smartcard.CardService.CardService

# ``smartcard`.`CardService`.`CardService``

class documentation

`class CardService(object):`

Known subclasses: `smartcard.PassThruCardService.PassThruCardService`

View In Hierarchy

Card service abstract class.

Static Method | `supports` | Undocumented
Method | `__del__` | Destructor. Disconnect card and destroy card service resources.
Method | `__init__` | Construct a new card service and bind to a smart card in a reader.
Instance Variable | `cardname` | Undocumented
Instance Variable | `connection` | Undocumented

def supports(cardname):
overridden in `smartcard.PassThruCardService.PassThruCardService`

Undocumented

def __del__(self):

Destructor. Disconnect card and destroy card service resources.

def __init__(self, connection, cardname=None):
overridden in `smartcard.PassThruCardService.PassThruCardService`

Construct a new card service and bind to a smart card in a reader.

Parameters
connection | the CardConnection used to access the smart card
cardname | Undocumented

cardname =

Undocumented

connection =

Undocumented